==> mysql-8.4_8.4.8.orig.tar.gz: mysql-8.4.8/sql/psi_memory_resource.cc <==
/* Copyright (c) 2023, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#include "psi_memory_resource.h"

#include "my_sys.h"                              // my_malloc
#include "storage/perfschema/pfs_instr_class.h"  // find_memory_class

mysql::binlog::event::resource::Memory_resource psi_memory_resource(
    PSI_memory_key key) {
  return mysql::binlog::event::resource::Memory_resource(
      [=](mysql::binlog::event::resource::Memory_resource::Size_t n)
          -> mysql::binlog::event::resource::Memory_resource::Ptr_t {
        return my_malloc(key, n, MYF(MY_WME | ME_FATALERROR));
      },
      my_free);
}

==> mysql-9.6.0.tar.gz: mysql-9.6.0/sql/psi_memory_resource.cc <==
/* Copyright (c) 2023, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#include "psi_memory_resource.h"

#include "my_sys.h"                              // my_malloc
#include "storage/perfschema/pfs_instr_class.h"  // find_memory_class

mysql::allocators::Memory_resource psi_memory_resource(PSI_memory_key key) {
  return mysql::allocators::Memory_resource(
      [=](mysql::allocators::Memory_resource::Size_t n)
          -> mysql::allocators::Memory_resource::Ptr_t {
        return my_malloc(key, n, MYF(MY_WME | ME_FATALERROR));
      },
      my_free);
}
